############################################################
Advanced Python Software Development - Gridka School of Life
############################################################

The main library to support the "Advanced Python Software Development" workshop at GridKa School 2017.
Implements Conway's "Game of Life" as a package.

Installation
############

Download this repository, and install it with ``python3 setup.py install``.

.. code::

    git clone https://github.com/MaineKuehn/workshop-advanced_python.git
    cd workshop-advanced_python
    python3 setup.py install
